pub(crate) fn endpoint() -> WithErrorResponses<Responses>Expand description
GET /health/live
Liveness endpoint.
Kubernetes (and others) use this endpoint to determine if the service is able to keep running.
In this service, liveness is assumed unless there are multiple panics generated by an endpoint in a short window.